# Generated by Django 2.2.17 on 2021-01-15 10:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_circle', '0025_remove_circle_team'),
    ]

    operations = [
        migrations.RenameField(
            model_name='circle',
            old_name='description',
            new_name='subtitle'
        ),
    ]



# Generated by Django 2.2.17 on 2021-01-15 10:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_circle', '0026_auto_20210115_1038'),
    ]

    operations = [
        migrations.AddField(
            model_name='circle',
            name='description',
            field=models.TextField(blank=True),
        ),
    ]
